List all available explores (dbt models) in the Lightdash project.

Explores in Lightdash represent your dbt models that have been exposed for querying and 
visualization. This tool helps you discover what data models are available to query.

Examples:
- "What explores are available in Lightdash?"
- "Show me all queryable dbt models"
- "List all data models I can use for charts"